From: tip-bot for Yunlong Song <tipbot@zytor.com>
To: linux-tip-commits@vger.kernel.org
Cc: a.p.zijlstra@chello.nl, linux-kernel@vger.kernel.org,
yunlong.song@huawei.com, hpa@zytor.com, paulus@samba.org,
tglx@linutronix.de, wangnan0@huawei.com, mingo@kernel.org,
acme@redhat.com
Subject: [tip:perf/core] perf tools: Fix the bash completion to support listing events for --event
Date: Sun, 22 Mar 2015 03:10:23 -0700 [thread overview]
Message-ID: <tip-3346b542f4165cb0007cfe3600866acbee67c686@git.kernel.org> (raw)
In-Reply-To: <1426685758-25488-6-git-send-email-yunlong.song@huawei.com>
Commit-ID: 3346b542f4165cb0007cfe3600866acbee67c686
Gitweb: http://git.kernel.org/tip/3346b542f4165cb0007cfe3600866acbee67c686
Author: Yunlong Song <yunlong.song@huawei.com>
AuthorDate: Wed, 18 Mar 2015 21:35:50 +0800
Committer: Arnaldo Carvalho de Melo <acme@redhat.com>
CommitDate: Thu, 19 Mar 2015 13:49:37 -0300
perf tools: Fix the bash completion to support listing events for --event
The bash completion only supports -e rather than --event, so fix it.
Example:
Before this patch:
$ perf record --event <TAB>
$
As shown above, the events of record does not come out.
After this patch:
$ perf record --event <TAB>
lignment-faults cpu/instructions/
L1-dcache-prefetch-misses node-prefetches
uncore_rbox_0/qpi0_idle_filt/
branch-instructions cpu/mem-loads/
L1-dcache-store-misses node-prefetch-misses
uncore_rbox_0/qpi1_date_response/
branch-load-misses cpu-migrations
L1-dcache-stores node-store-misses
uncore_rbox_0/qpi1_filt_send/
branch-loads dTLB-load-misses
L1-icache-load-misses node-stores
uncore_rbox_0/qpi1_idle_filt/
...
As shown above, the events of record can come out now.
Signed-off-by: Yunlong Song <yunlong.song@huawei.com>
Tested-by: Arnaldo Carvalho de Melo <acme@redhat.com>
Cc: Paul Mackerras <paulus@samba.org>
Cc: Peter Zijlstra <a.p.zijlstra@chello.nl>
Cc: Wang Nan <wangnan0@huawei.com>
Link: http://lkml.kernel.org/r/1426685758-25488-6-git-send-email-yunlong.song@huawei.com
Signed-off-by: Arnaldo Carvalho de Melo <acme@redhat.com>
---
tools/perf/perf-completion.sh | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/tools/perf/perf-completion.sh b/tools/perf/perf-completion.sh
index 4b58ac2..3e25d3e 100644
--- a/tools/perf/perf-completion.sh
+++ b/tools/perf/perf-completion.sh
@@ -137,8 +137,8 @@ __perf_main ()
cmds=$($cmd --list-cmds)
fi
__perfcomp "$cmds" "$cur"
- # List possible events for -e option
- elif [[ $prev == "-e" && $prev_skip_opts == @(record|stat|top) ]]; then
+ # List possible events for -e and --event option
+ elif [[ $prev == @("-e"|"--event") && $prev_skip_opts == @(record|stat|top) ]]; then
evts=$($cmd list --raw-dump)
__perfcomp_colon "$evts" "$cur"
else
next prev parent reply other threads:[~2015-03-22 10:10 UTC|newest]
Thread overview: 27+ messages / expand[flat|nested] mbox.gz Atom feed top
2015-03-18 13:35 [PATCH 00/13] perf tools: Make some improvements and fixes Yunlong Song
2015-03-18 13:35 ` [PATCH 01/13] perf tools: Fix the bash completion for listing options of perf subcommand Yunlong Song
2015-03-22 10:09 ` [tip:perf/core] " tip-bot for Yunlong Song
2015-03-18 13:35 ` [PATCH 02/13] perf tools: Fix the bash completion for listing subsubcommands " Yunlong Song
2015-03-22 10:09 ` [tip:perf/core] " tip-bot for Yunlong Song
2015-03-18 13:35 ` [PATCH 03/13] perf tools: Provide the right bash completion for listing options of perf subcommand subsubcommand Yunlong Song
2015-03-22 10:09 ` [tip:perf/core] " tip-bot for Yunlong Song
2015-03-18 13:35 ` [PATCH 04/13] perf tools: Fix the bash completion for listing events of perf subcommand record|stat|top -e Yunlong Song
2015-03-22 10:10 ` [tip:perf/core] " tip-bot for Yunlong Song
2015-03-18 13:35 ` [PATCH 05/13] perf tools: Fix the bash completion to support listing events for --event Yunlong Song
2015-03-22 10:10 ` tip-bot for Yunlong Song [this message]
2015-03-18 13:35 ` [PATCH 06/13] perf tools: Fix the bash completion for listing subcommands of perf Yunlong Song
2015-03-22 10:10 ` [tip:perf/core] " tip-bot for Yunlong Song
2015-03-18 13:35 ` [PATCH 07/13] perf tools: Add the bash completion for listing subsubcommands of perf data Yunlong Song
2015-03-22 10:11 ` [tip:perf/core] " tip-bot for Yunlong Song
2015-03-18 13:35 ` [PATCH 08/13] perf tools: Add the bash completion for listing subsubcommands of perf help Yunlong Song
2015-03-22 10:11 ` [tip:perf/core] " tip-bot for Yunlong Song
2015-03-18 13:35 ` [PATCH 09/13] perf tools: Add the bash completion for listing subsubcommands of perf script Yunlong Song
2015-03-22 10:11 ` [tip:perf/core] " tip-bot for Yunlong Song
2015-03-18 13:35 ` [PATCH 10/13] perf tools: Add the bash completion for listing subsubcommands of perf test Yunlong Song
2015-03-22 10:11 ` [tip:perf/core] " tip-bot for Yunlong Song
2015-03-18 13:35 ` [PATCH 11/13] perf tools: Add the bash completion for listing subsubcommands of perf timechart Yunlong Song
2015-03-22 10:12 ` [tip:perf/core] " tip-bot for Yunlong Song
2015-03-18 13:35 ` [PATCH 12/13] perf tools: Add the bash completion for listing subsubcommands of perf trace Yunlong Song
2015-03-22 10:12 ` [tip:perf/core] " tip-bot for Yunlong Song
2015-03-18 13:35 ` [PATCH 13/13] perf tools: Avoid confusion with preloaded bash function for perf bash completion Yunlong Song
2015-03-22 10:12 ` [tip:perf/core] " tip-bot for Yunlong Song
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tip-3346b542f4165cb0007cfe3600866acbee67c686@git.kernel.org \
--to=tipbot@zytor.com \
--cc=a.p.zijlstra@chello.nl \
--cc=acme@redhat.com \
--cc=hpa@zytor.com \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-tip-commits@vger.kernel.org \
--cc=mingo@kernel.org \
--cc=paulus@samba.org \
--cc=tglx@linutronix.de \
--cc=wangnan0@huawei.com \
--cc=yunlong.song@huawei.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
Powered by JetHome